@@ -1,4 +1,5 @@
 #include "Common/Common.h"
+#include "AppSettings.h"
 
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
@@ -32,6 +33,10 @@
 #ifdef HAVE_POPT
 #include <popt.h>
 
+#ifndef _
+#define _(_x)s gettext(_x)
+#endif
+
 static const struct poptOption options[] = {
   {"timedata", 'w', POPT_ARG_NONE, NULL, 1, "Write basic timing information to stdout", NULL},
   {"preferences", 'p', POPT_ARG_NONE, NULL, 1, "Show preferences window only", NULL},
@@ -186,6 +191,11 @@ int main(int argc, char *argv[]) {
 
   //  g_type_class_ref(dasher_gtk_text_view_get_type());
 
+  g_set_application_name (_("Dasher"));
+#ifndef WITH_MAEMO
+  gtk_window_set_default_icon_name ("dasher");
+#endif
+
 #ifdef WITH_GPE
   xml = glade_xml_new(PROGDATA "/dashergpe.glade", NULL, NULL);
 #elif WITH_MAEMO
@@ -224,13 +234,34 @@ int main(int argc, char *argv[]) {
 
   InitialiseMainWindow(argc, argv, xml);
 
+
+
 #ifdef WITH_GPE
   gtk_window_set_decorated(GTK_WINDOW(window), false);
 #endif
 
 #ifndef WITH_MAEMO
-  gtk_window_set_icon_from_file(GTK_WINDOW(window), DATADIR "/icons/hicolor/48x48/apps/dasher.png", NULL);
   gtk_widget_show(window);
+
+
+ if(get_app_parameter_bool(APP_BP_KEYBOARD_MODE)) {
+    XWMHints wm_hints;
+    Atom wm_window_protocols[3];
+    
+    wm_window_protocols[0] = gdk_x11_get_xatom_by_name("WM_DELETE_WINDOW");
+    wm_window_protocols[1] = gdk_x11_get_xatom_by_name("_NET_WM_PING");
+    wm_window_protocols[2] = gdk_x11_get_xatom_by_name("WM_TAKE_FOCUS");
+    
+    wm_hints.flags = InputHint;
+    wm_hints.input = False;
+    
+    XSetWMHints(GDK_WINDOW_XDISPLAY(window->window), GDK_WINDOW_XWINDOW(window->window), &wm_hints);
+    XSetWMProtocols(GDK_WINDOW_XDISPLAY(window->window), GDK_WINDOW_XWINDOW(window->window), wm_window_protocols, 3);
+    gdk_window_add_filter(window->window, dasher_discard_take_focus_filter, NULL);
+    gtk_window_set_keep_above(GTK_WINDOW(window), true);
+  } 
+
+
 #else
   appview = HILDON_APPVIEW( hildon_appview_new(NULL) );
   app = HILDON_APP( hildon_app_new() );
